@@ -11,6 +11,8 @@ def http_error_message(url: str, status_code: int) -> str:
             client_error = "Unauthorized"
         case 404:
             client_error = "Not Found"
+        case 429:
+            client_error = "Too Many Requests"
         case _:
             pass
 
